package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.SysSmsBlacklist;

/**
 * 短信手机黑名单Service接口
 * 
 * @author ruoyi
 * @date 2025-09-12
 */
public interface ISysSmsBlacklistService 
{
    /**
     * 查询短信手机黑名单
     * 
     * @param id 短信手机黑名单主键
     * @return 短信手机黑名单
     */
    public SysSmsBlacklist selectSysSmsBlacklistById(Long id);

    /**
     * 查询短信手机黑名单列表
     * 
     * @param sysSmsBlacklist 短信手机黑名单
     * @return 短信手机黑名单集合
     */
    public List<SysSmsBlacklist> selectSysSmsBlacklistList(SysSmsBlacklist sysSmsBlacklist);

    /**
     * 新增短信手机黑名单
     * 
     * @param sysSmsBlacklist 短信手机黑名单
     * @return 结果
     */
    public int insertSysSmsBlacklist(SysSmsBlacklist sysSmsBlacklist);

    /**
     * 修改短信手机黑名单
     * 
     * @param sysSmsBlacklist 短信手机黑名单
     * @return 结果
     */
    public int updateSysSmsBlacklist(SysSmsBlacklist sysSmsBlacklist);

    /**
     * 批量删除短信手机黑名单
     * 
     * @param ids 需要删除的短信手机黑名单主键集合
     * @return 结果
     */
    public int deleteSysSmsBlacklistByIds(Long[] ids);

    /**
     * 删除短信手机黑名单信息
     * 
     * @param id 短信手机黑名单主键
     * @return 结果
     */
    public int deleteSysSmsBlacklistById(Long id);
}
