package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.SysSmsBlacklist;
import com.ruoyi.system.service.ISysSmsBlacklistService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 短信手机黑名单Controller
 * 
 * @author ruoyi
 * @date 2025-09-12
 */
@RestController
@RequestMapping("/system/blacklist")
public class SysSmsBlacklistController extends BaseController
{
    @Autowired
    private ISysSmsBlacklistService sysSmsBlacklistService;

    /**
     * 查询短信手机黑名单列表
     */
    @PreAuthorize("@ss.hasPermi('system:blacklist:list')")
    @GetMapping("/list")
    public TableDataInfo list(SysSmsBlacklist sysSmsBlacklist)
    {
        startPage();
        List<SysSmsBlacklist> list = sysSmsBlacklistService.selectSysSmsBlacklistList(sysSmsBlacklist);
        return getDataTable(list);
    }

    /**
     * 导出短信手机黑名单列表
     */
    @PreAuthorize("@ss.hasPermi('system:blacklist:export')")
    @Log(title = "短信手机黑名单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysSmsBlacklist sysSmsBlacklist)
    {
        List<SysSmsBlacklist> list = sysSmsBlacklistService.selectSysSmsBlacklistList(sysSmsBlacklist);
        ExcelUtil<SysSmsBlacklist> util = new ExcelUtil<SysSmsBlacklist>(SysSmsBlacklist.class);
        util.exportExcel(response, list, "短信手机黑名单数据");
    }

    /**
     * 获取短信手机黑名单详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:blacklist:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(sysSmsBlacklistService.selectSysSmsBlacklistById(id));
    }

    /**
     * 新增短信手机黑名单
     */
    @PreAuthorize("@ss.hasPermi('system:blacklist:add')")
    @Log(title = "短信手机黑名单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SysSmsBlacklist sysSmsBlacklist)
    {
        return toAjax(sysSmsBlacklistService.insertSysSmsBlacklist(sysSmsBlacklist));
    }

    /**
     * 修改短信手机黑名单
     */
    @PreAuthorize("@ss.hasPermi('system:blacklist:edit')")
    @Log(title = "短信手机黑名单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SysSmsBlacklist sysSmsBlacklist)
    {
        return toAjax(sysSmsBlacklistService.updateSysSmsBlacklist(sysSmsBlacklist));
    }

    /**
     * 删除短信手机黑名单
     */
    @PreAuthorize("@ss.hasPermi('system:blacklist:remove')")
    @Log(title = "短信手机黑名单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sysSmsBlacklistService.deleteSysSmsBlacklistByIds(ids));
    }
}
